#!/bin/sh
#
#  COPYRIGHT (C) 2019 MITSUBISHI ELECTRIC CORPORATION
#  ALL RIGHTS RESERVED
#
#  Uninstall Printer Driver Script
#  For CP-D90D Digital Color Printer
#  Ver.3.00 for macOS 10.13 10.14
#


TARGET_DIR_VENDOR="MITSUBISHI"
TARGET_DIR_ICONS="Icons"
TARGET_DIR_FILTER="filter"
TARGET_PPD="CP90.ppd.gz"
TARGET_ICON="CP90.icns"
TARGET_FILTER="CP90Filter"
TARGET_COMFILTER="CP90comFilter"
TARGET_PKG_ID="com.mitsubishi.CP90"

rm_printer() {
    for model in $*
    do
      /usr/sbin/lpadmin -x $model 2> /dev/null
    done
    return 0
}

remove_file() {
    for file in $*
    do
        if [ -f "$file" ]; then
            sudo rm -f "$file"
            if [ $? != 0 ]; then
                return 1
            fi
        fi
    done
    return 0
}

remove_dir() {
    if [ -d "$*" ]; then
        sudo rm -rf "$*"
        if [ $? != 0 ]; then
            return 1
        fi
    fi
    return 0
}

remove_emptydir() {
    if [ -d $* ]; then
        local isEmpty=1
        for file in $(ls "$*"); do
            local isEmpty=0
            break
        done
        if [ $isEmpty = 1 ]; then
            sudo rm -rf "$*"
            if [ $? != 0 ]; then
                return 1
            fi
        fi
    fi
    return 0
}

  remove_driver() {
#    if remove_dir "/Library/Printers/$TARGET_DIR_VENDOR/$TARGET_USBCLASSDIRVER"; then :; else
#        return 1
#    fi
    if remove_file $(find /Library/Printers/PPDs -name "$TARGET_PPD"); then :; else
        return 1
    fi
    if remove_file "/Library/Printers/$TARGET_DIR_VENDOR/$TARGET_DIR_ICONS/$TARGET_ICON"; then :; else
        return 1
    fi
    if remove_emptydir "/Library/Printers/$TARGET_DIR_VENDOR/$TARGET_DIR_ICONS"; then :; else
        return 1
    fi
    if remove_file "/Library/Printers/$TARGET_DIR_VENDOR/$TARGET_DIR_FILTER/$TARGET_FILTER"; then :; else
        return 1
    fi
    if remove_file "/Library/Printers/$TARGET_DIR_VENDOR/$TARGET_DIR_FILTER/$TARGET_COMFILTER"; then :; else
        return 1
    fi
    if remove_emptydir "/Library/Printers/$TARGET_DIR_VENDOR/$TARGET_DIR_FILTER"; then :; else
        return 1
    fi
    if remove_emptydir "/Library/Printers/$TARGET_DIR_VENDOR"; then :; else
        return 1
    fi

    sudo pkgutil --forget $TARGET_PKG_ID > /dev/null 2>&1

    return 0
}

do_reboot() {
    echo "Uninstallation was completed."

    while true
    do
        echo "Is a computer rebooted?(Y/N): "
        read isReboot

        case "$isReboot" in
            "y" | "Y" )
                osascript -e 'tell application "System Events"' -e 'restart' -e 'end tell'
                break;;
            "n" | "N" )
                break;;
            * )
                ;;
        esac
    done
    return 0
}

rm_printer $(find /etc/cups/ppd -name "MITSUBISHI_CPD90D*.ppd" -exec basename {} .ppd \;)
if remove_driver; then
    do_reboot
else
    echo "Uninstallation went wrong."
fi

exit 0
